@@ -3,7 +3,8 @@
 #![allow(dead_code)]
 
 use criterion::*;
-use uri_rs::parser::parsers::{Elms};
+use uri_rs::parser;
+use uri_rs::parser::parsers::Elms;
 
 criterion_group!(benches, criterion_benchmark);
 
@@ -12,7 +13,7 @@ const uri: &'static str =
 
 #[inline]
 fn uri_parsers_uri() {
-  let _ = uri_rs::parser::parsers::uri_parsers::uri(Elms::new(uri.as_bytes())).unwrap();
+  let _ = parser::parsers::uri_parsers::uri(Elms::new(uri.as_bytes())).unwrap();
 }
 
 const hier_part: &'static str = "//user1:pass1@localhost:80801";
@@ -20,13 +21,13 @@ const hier_part: &'static str = "//user1:pass1@localhost:80801";
 #[inline]
 fn uri_hier_part_parsers_hier_part() {
   let _ =
-    uri_rs::parser::parsers::hier_part_parsers::hier_part(Elms::new(hier_part.as_bytes())).unwrap();
+      parser::parsers::hier_part_parsers::hier_part(Elms::new(hier_part.as_bytes())).unwrap();
 }
 
 const query: &'static str = "key1=value1&key2=value2&key1=value2";
 
 fn uri_query_parsers_query() {
-  let _ = uri_rs::parser::parsers::query_parsers::query(Elms::new(query.as_bytes())).unwrap();
+  let _ = parser::parsers::query_parsers::query(Elms::new(query.as_bytes())).unwrap();
 }
 
 fn criterion_benchmark(c: &mut Criterion) {
